@@ -65,27 +65,36 @@ class Engine:
         self.runtime = runtime
 
     # api
-    def run_pipeline(self, pipeline: dict, root_pipeline_data: Optional[dict] = None, **options):
+    def run_pipeline(
+        self,
+        pipeline: dict,
+        root_pipeline_data: Optional[dict] = None,
+        root_pipeline_context: Optional[dict] = None,
+        **options
+    ):
         """
         运行流程
 
         :param pipeline: 流程数据
         :type pipeline: dict
         :param root_pipeline_data 根流程数据
-        :type root_pipeline_data dict
+        :type root_pipeline_data: dict
+        :param root_pipeline_context 根流程上下文
+        :type root_pipeline_context: dict
         """
 
         root_pipeline_data = {} if root_pipeline_data is None else root_pipeline_data
+        root_pipeline_context = {} if root_pipeline_context is None else root_pipeline_context
         cycle_tolerate = options.get("cycle_tolerate", False)
         validator.validate_and_process_pipeline(pipeline, cycle_tolerate)
 
-        self.runtime.pre_prepare_run_pipeline(pipeline, root_pipeline_data, **options)
+        self.runtime.pre_prepare_run_pipeline(pipeline, root_pipeline_data, root_pipeline_context, **options)
 
-        process_id = self.runtime.prepare_run_pipeline(pipeline, root_pipeline_data, **options)
+        process_id = self.runtime.prepare_run_pipeline(pipeline, root_pipeline_data, root_pipeline_context, **options)
         # execute from start event
         self.runtime.execute(process_id, pipeline["start_event"]["id"])
 
-        self.runtime.post_prepare_run_pipeline(pipeline, root_pipeline_data, **options)
+        self.runtime.post_prepare_run_pipeline(pipeline, root_pipeline_data, root_pipeline_context, **options)
 
     def pause_pipeline(self, pipeline_id: str):
         """
