@@ -239,25 +239,33 @@ class EngineAPIHooksMixin:
     """
 
     @abstractmethod
-    def pre_prepare_run_pipeline(self, pipeline: dict, root_pipeline_data: dict, **options):
+    def pre_prepare_run_pipeline(
+        self, pipeline: dict, root_pipeline_data: dict, root_pipeline_context: dict, **options
+    ):
         """
         调用 pre_prepare_run_pipeline 前执行的钩子
 
         :param pipeline: 流程描述对象
         :type pipeline: dict
         :param root_pipeline_data 根流程数据
-        :type root_pipeline_data dict
+        :type root_pipeline_data: dict
+        :param root_pipeline_context 根流程上下文
+        :type root_pipeline_context: dict
         """
 
     @abstractmethod
-    def post_prepare_run_pipeline(self, pipeline: dict, root_pipeline_data: dict, **options):
+    def post_prepare_run_pipeline(
+        self, pipeline: dict, root_pipeline_data: dict, root_pipeline_context: dict, **options
+    ):
         """
         调用 pre_prepare_run_pipeline 后执行的钩子
 
         :param pipeline: 流程描述对象
         :type pipeline: dict
         :param root_pipeline_data 根流程数据
-        :type root_pipeline_data dict
+        :type root_pipeline_data: dict
+        :param root_pipeline_context 根流程上下文
+        :type root_pipeline_context: dict
         """
 
     @abstractmethod
@@ -1337,7 +1345,9 @@ class EngineRuntimeInterface(
     metaclass=ABCMeta,
 ):
     @abstractmethod
-    def prepare_run_pipeline(self, pipeline: dict, root_pipeline_data: dict, **options) -> int:
+    def prepare_run_pipeline(
+        self, pipeline: dict, root_pipeline_data: dict, root_pipeline_context: dict, **options
+    ) -> int:
         """
         进行 pipeline 执行前的准备工作，并返回 进程 ID，该函数执行完成后即代表
         pipeline 是随时可以通过 execute(process_id, start_event_id) 启动执行的
@@ -1349,7 +1359,9 @@ class EngineRuntimeInterface(
         :param pipeline: pipeline 描述对象
         :type pipeline: dict
         :param root_pipeline_data 根流程数据
-        :type root_pipeline_data dict
+        :type root_pipeline_data: dict
+        :param root_pipeline_context 根流程上下文
+        :type root_pipeline_context: dict
         :return: 进程 ID
         :rtype: str
         """
