@@ -19,24 +19,37 @@ from typing import Optional
 
 from werkzeug.local import Local
 
+from .utils.object import Representable
+
 _local = Local()
 
 
-def set_node_id(node_id: str):
+class CurrentNodeInfo(Representable):
+    def __init__(self, node_id: str, version: str, loop: int):
+        self.node_id = node_id
+        self.version = version
+        self.loop = loop
+
+
+def set_node_info(node_info: CurrentNodeInfo):
     """
-    将当前进程/线程/协程 Local 中的节点 ID 设置为 node_id
+    设置当前进程/线程/协程 Local 中的当前节点信息
 
     :param node_id: 节点 ID
     :type node_id: str
+    :param version: 节点版本
+    :type version: str
+    :param loop: 重入次数
+    :type loop: int
     """
-    _local.currnet_node_id = node_id
+    _local.current_node_info = node_info
 
 
-def get_node_id() -> Optional[str]:
+def get_node_info() -> Optional[CurrentNodeInfo]:
     """
-    获取当前进程/线程/协程正在处理的节点 ID
+    获取当前进程/线程/协程正在处理的节点 ID，版本及重入次数
 
     :return: 节点 ID
     :rtype: [type]
     """
-    return getattr(_local, "currnet_node_id", None)
+    return getattr(_local, "current_node_info", None)
